import _extends from "@babel/runtime/helpers/extends";

/**
 * File: /src/components/Grid/index.tsx
 * Project: @native-theme-ui/core
 * File Created: 27-06-2022 10:03:43
 * Author: Ajithkrm6
 * -----
 * Last Modified: 09-09-2022 13:11:49
 * Modified By: Clay Risser
 * -----
 * Risser Labs LLC (c) Copyright 2021 - 2022
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */
import React from "react";
import { FlatList, View } from "react-native";
import { useBreakpointIndex, styled } from "dripsy";
import { useAutoContrast } from "@risserlabs/auto-contrast";
import { Box } from "../Box";
import { useSplitProps } from "./props";
const themeKey = "grids";
const defaultStyle = {
  width: "100%"
};
const StyledBox = styled(Box, {
  themeKey
})(defaultStyle);

const Item = _ref => {
  let {
    item
  } = _ref;
  return /*#__PURE__*/React.createElement(View, {
    style: {
      flex: 1,
      maxWidth: "".concat(100 / item.columns, "%")
    }
  }, /*#__PURE__*/React.createElement(Box, {
    style: {
      width: "100%"
    }
  }, item.node));
};

export const Grid = props => {
  const breakpointIndex = useBreakpointIndex();
  const sx = useAutoContrast(props, defaultStyle, themeKey);
  const {
    baseProps,
    flatListProps
  } = useSplitProps(props, sx);
  let columns = typeof props.columns === "number" ? props.columns : 4;

  if (Array.isArray(props.columns) && breakpointIndex < props.columns.length) {
    columns = props.columns[breakpointIndex];
  }

  const data = (Array.isArray(props.children) ? props.children : [props.children]).map(node => ({
    node,
    columns
  }));
  return /*#__PURE__*/React.createElement(StyledBox // eslint-disable-next-line @typescript-eslint/no-explicit-any
  , _extends({}, baseProps, {
    sx: sx,
    style: {
      flex: columns
    }
  }), /*#__PURE__*/React.createElement(FlatList, _extends({}, flatListProps, {
    key: columns,
    data: data,
    numColumns: columns,
    renderItem: Item
  })));
};
//# sourceMappingURL=index.js.map