import _extends from "@babel/runtime/helpers/extends";
import "core-js/modules/web.dom-collections.iterator.js";

/**
 * File: /src/components/Image/index.tsx
 * Project: @native-theme-ui/core
 * File Created: 13-06-2022 00:51:44
 * Author: Clay Risser
 * -----
 * Last Modified: 31-10-2022 07:11:37
 * Modified By: Clay Risser
 * -----
 * Risser Labs LLC (c) Copyright 2021 - 2022
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/* eslint-disable @typescript-eslint/no-explicit-any */
import { XMLParser } from "fast-xml-parser";
import React, { useState, useEffect } from "react";
import { styled } from "dripsy";
import { SvgUri } from "react-native-svg";
import { Image as RNImage, Platform, StyleSheet } from "react-native";
import { useCalculatedSx } from "@risserlabs/auto-contrast";
import { Box } from "../Box";
import { useSplitProps } from "./props";
const logger = console;
const defaultStyle = {
  height: "auto",
  maxWidth: "100%",
  width: "100%"
};
const StyledImage = styled(RNImage, {
  themeKey: "images"
})(defaultStyle);
const StyledSvgUri = styled(SvgUri, {
  themeKey: "images"
})(defaultStyle);
const StyledOuterBox = styled(Box)({
  position: "relative",
  overflow: "hidden"
});
const parser = new XMLParser({
  ignoreAttributes: false,
  attributeNamePrefix: "@_",
  allowBooleanAttributes: true
});
export const Image = props => {
  var _props$src, _props$src2, _source, _source2, _source2$uri, _source5;

  const [imageRatio, setImageRatio] = useState();
  const sx = useCalculatedSx({ ...props.sx
  });
  const style = StyleSheet.flatten(props.style || {});
  style.resizeMode = getResizeMode(sx, style.objectFit, style.resizeMode);
  delete style.objectFit;
  delete sx.objectFit;
  const {
    baseProps,
    baseStyle,
    baseSx,
    innerStyle,
    innerSx,
    motiPressableProps
  } = useSplitProps(props, sx);
  const isMotiPressable = !!Object.keys(motiPressableProps).length;
  let {
    svg
  } = props;
  const styledImageProps = { ...baseProps
  };
  let source = props.src;

  if (typeof props.src === "string") {
    source = {
      uri: props.src
    };
  } else if ((_props$src = props.src) !== null && _props$src !== void 0 && _props$src.localUri && (_props$src2 = props.src) !== null && _props$src2 !== void 0 && _props$src2.type) {
    source = {
      uri: props.src.uri
    };

    if (props.src.type === "svg" && typeof svg === "undefined") {
      svg = true;
    }
  }

  if (Platform.OS === "web" && typeof ((_source = source) === null || _source === void 0 ? void 0 : _source.uri) === "string" && ((_source2 = source) === null || _source2 === void 0 ? void 0 : (_source2$uri = _source2.uri) === null || _source2$uri === void 0 ? void 0 : _source2$uri.substring(0, 2)) === "//") {
    var _source3, _source3$uri, _source4;

    source.uri = ((_source3 = source) === null || _source3 === void 0 ? void 0 : (_source3$uri = _source3.uri) === null || _source3$uri === void 0 ? void 0 : _source3$uri.substring(1)) || ((_source4 = source) === null || _source4 === void 0 ? void 0 : _source4.uri);
  }

  delete styledImageProps.src;
  const uri = typeof source === "number" ? source : (_source5 = source) === null || _source5 === void 0 ? void 0 : _source5.uri;
  const calculateHeight = style.height === "auto" || typeof style.height === "undefined" && (typeof sx.height === "undefined" || sx.height === "auto");
  useEffect(() => {
    if (typeof uri !== "number" && uri && !imageRatio && calculateHeight) {
      if (svg) {
        if (uri) {
          (async () => {
            const res = await fetch(uri);

            try {
              var _xml$svg, _xml$svg2;

              const xml = parser.parse(await res.text());
              const width = parseInt(xml === null || xml === void 0 ? void 0 : (_xml$svg = xml.svg) === null || _xml$svg === void 0 ? void 0 : _xml$svg["@_width"]);
              const height = parseInt(xml === null || xml === void 0 ? void 0 : (_xml$svg2 = xml.svg) === null || _xml$svg2 === void 0 ? void 0 : _xml$svg2["@_height"]);

              if (typeof width === "number" && !Number.isNaN(width) && typeof height === "number" && !Number.isNaN(height)) {
                setImageRatio(width / height);
              }
            } catch (err) {
              logger.error(err);
            }
          })();
        }
      } else {
        RNImage.getSize(uri, (width, height) => {
          setImageRatio(width / height);
        });
      }
    }
  }, [uri, imageRatio, calculateHeight, props.src]);

  function renderImage(props) {
    if (!props.src || !uri) /*#__PURE__*/React.createElement(Box, props);

    if (svg && Platform.OS !== "web") {
      var _style$height, _style$width;

      return /*#__PURE__*/React.createElement(StyledSvgUri, _extends({}, props, {
        onLayout: e => {
          console.log("layoutEvent", e.nativeEvent);
        },
        height: (_style$height = style.height) !== null && _style$height !== void 0 ? _style$height : sx.height,
        uri: uri,
        width: (_style$width = style.width) !== null && _style$width !== void 0 ? _style$width : sx.width
      }));
    }

    console.log("PROPS", props);
    console.log("SOURCE", source);
    return /*#__PURE__*/React.createElement(StyledImage, _extends({}, props, {
      source: source
    }));
  }

  if (calculateHeight && imageRatio) {
    return /*#__PURE__*/React.createElement(StyledOuterBox, _extends({}, motiPressableProps, {
      sx: baseSx,
      style: baseStyle
    }), /*#__PURE__*/React.createElement(Box, {
      style: {
        height: 0,
        paddingBottom: "".concat(100 / imageRatio, "%"),
        width: "100%"
      }
    }), renderImage({ ...styledImageProps,
      sx: innerSx,
      style: { ...innerStyle,
        position: "absolute",
        top: 0,
        right: 0,
        bottom: 0,
        left: 0
      }
    }));
  }

  if (isMotiPressable) {
    return /*#__PURE__*/React.createElement(StyledOuterBox, _extends({}, motiPressableProps, {
      sx: baseSx,
      style: { ...baseStyle
      }
    }), renderImage({ ...styledImageProps,
      sx: innerSx,
      style: { ...innerStyle,
        overflow: "visible",
        width: "100%",
        height: "100%"
      }
    }));
  }

  return renderImage({ ...styledImageProps,
    sx,
    style
  });
};

function getResizeMode(sx, objectFit, resizeMode) {
  if (resizeMode) return resizeMode;
  if (objectFit === "fill") return "stretch";
  if (objectFit === "cover" || objectFit === "contain") return objectFit;
  if (sx.objectFit === "fill") return "stretch";

  if (sx.objectFit === "cover" || sx.objectFit === "contain") {
    return sx.objectFit;
  }

  return "contain";
}
//# sourceMappingURL=index.js.map