import _extends from "@babel/runtime/helpers/extends";
import "core-js/modules/web.dom-collections.iterator.js";

/**
 * File: /src/components/Input/index.tsx
 * Project: @native-theme-ui/core
 * File Created: 13-06-2022 00:51:44
 * Author: Clay Risser
 * -----
 * Last Modified: 11-09-2022 06:13:29
 * Modified By: Clay Risser
 * -----
 * Risser Labs LLC (c) Copyright 2021 - 2022
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/* eslint-disable @typescript-eslint/no-explicit-any */
import React, { useCallback, useState } from "react";
import { styled } from "dripsy";
import { TextInput } from "react-native";
import { useAutoContrast, useThemeLookup } from "@risserlabs/auto-contrast";
import { forwardThemeKey } from "../../util";
const themeKey = "forms";
const defaultStyle = {
  borderRadius: 4,
  borderStyle: "solid",
  borderWidth: 1,
  color: "text",
  fontSize: 1,
  p: 2
};
const StyledTextInput = styled(TextInput, {
  themeKey,
  defaultVariant: "input"
})(defaultStyle);
export const Input = props => {
  var _props$value;

  const sx = useAutoContrast(props, defaultStyle, themeKey);
  const themeLookup = useThemeLookup(forwardThemeKey(props, themeKey));
  const [value, setValue] = useState(props.defaultValue || "");
  const handleChangeText = useCallback(text => {
    setValue(text);
    if (props.onChangeText) props.onChangeText(text);
  }, [props.onChangeText]);
  const clonedProps = { ...props
  };
  delete clonedProps.defaultValue;
  delete clonedProps.children;
  return /*#__PURE__*/React.createElement(StyledTextInput, _extends({}, clonedProps, {
    onChangeText: handleChangeText,
    placeholderTextColor: themeLookup("color", props.placeholderTextColor),
    selectionColor: themeLookup("color", props.selectionColor),
    sx: sx,
    underlineColorAndroid: themeLookup("color", props.underlineColorAndroid),
    value: (_props$value = props.value) !== null && _props$value !== void 0 ? _props$value : value
  }));
};
//# sourceMappingURL=index.js.map