import _extends from "@babel/runtime/helpers/extends";
import "core-js/modules/web.dom-collections.iterator.js";

/**
 * File: /src/components/Switch/index.tsx
 * Project: @native-theme-ui/core
 * File Created: 17-06-2022 01:05:11
 * Author: Lavanya Katari
 * -----
 * Last Modified: 11-09-2022 07:41:01
 * Modified By: Clay Risser
 * -----
 * Risser Labs LLC (c) Copyright 2021 - 2022
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

/* eslint-disable @typescript-eslint/no-explicit-any,@typescript-eslint/no-non-null-assertion */
import React, { useCallback, useState, useEffect } from "react";
import { Easing } from "react-native-reanimated";
import { Platform, StyleSheet } from "react-native";
import { styled } from "dripsy";
import { useAutoContrast } from "@risserlabs/auto-contrast";
import { Box } from "../Box";
import { Label } from "../Label";
import { useSplitProps } from "./props";
const themeKey = "forms";
const StyledOuterBox = styled(Box, {
  themeKey,
  defaultVariant: "switch"
})(_ref => {
  let {
    showCursor
  } = _ref;
  return { ...Platform.select({
      web: {
        cursor: showCursor ? "pointer" : "default"
      }
    }),
    alignSelf: "flex-start",
    alignItems: "center"
  };
});
const StyledGutterBox = styled(Box, {
  themeKey,
  defaultVariant: "switch"
})({});
export const Switch = props => {
  var _props$defaultChecked, _props$checked, _props$checked3, _props$checked4, _props$checked5;

  const [checked, setChecked] = useState((_props$defaultChecked = props.defaultChecked) !== null && _props$defaultChecked !== void 0 ? _props$defaultChecked : false);
  const sx = useAutoContrast(props, {}, themeKey);
  const style = StyleSheet.flatten(props.style || {});
  const {
    baseProps,
    checkboxProps,
    innerSx,
    innerStyle,
    baseStyle,
    baseSx
  } = useSplitProps(props, sx);
  const bg = style.backgroundColor || sx.backgroundColor || sx.bg || "primary";
  let from = {
    transform: [{
      translateX: ((_props$checked = props.checked) !== null && _props$checked !== void 0 ? _props$checked : checked) ? props.size : 0
    }]
  };
  useEffect(() => {
    var _props$checked2;

    from = {
      transform: [{
        translateX: ((_props$checked2 = props.checked) !== null && _props$checked2 !== void 0 ? _props$checked2 : checked) ? 0 : props.size
      }]
    };
  }, [props.size, props.checked, checked]);
  const handlePress = useCallback(() => {
    if (props.disabled) return;
    setChecked(checked => !checked);
    if (props.onPress) props.onPress();
  }, [props.disabled]);
  return /*#__PURE__*/React.createElement(StyledOuterBox, _extends({}, baseProps, {
    sx: baseSx,
    style: { ...baseStyle,
      flexDirection: "row"
    },
    showCursor: !!(props.accessibilityRole === "link" || !props.disabled),
    onPress: handlePress
  }), Platform.OS === "web" && /*#__PURE__*/React.createElement("input", _extends({}, checkboxProps, {
    checked: (_props$checked3 = props.checked) !== null && _props$checked3 !== void 0 ? _props$checked3 : checked,
    readOnly: true,
    type: "checkbox",
    style: {
      height: 1,
      opacity: 0,
      overflow: "hidden",
      position: "absolute",
      width: 1,
      zIndex: -1
    }
  })), /*#__PURE__*/React.createElement(StyledGutterBox, {
    sx: { ...innerSx,
      ...(props.label ? {
        mr: 2
      } : {}),
      bg: ((_props$checked4 = props.checked) !== null && _props$checked4 !== void 0 ? _props$checked4 : checked) ? bg : "gray"
    },
    style: { ...innerStyle,
      alignItems: "center",
      borderRadius: props.size,
      flexDirection: "row",
      flexShrink: 0,
      height: props.size + props.gutter * 2,
      padding: props.gutter,
      width: props.size * 2 + props.gutter * 2
    },
    transition: {
      duration: 0,
      type: "timing"
    }
  }, /*#__PURE__*/React.createElement(Box, {
    from: from,
    animate: {
      transform: [{
        translateX: ((_props$checked5 = props.checked) !== null && _props$checked5 !== void 0 ? _props$checked5 : checked) ? props.size : 0
      }]
    },
    sx: {
      bg: "white",
      boxShadow: "0 1px 2px rgba(0, 0, 0, 0.1)",
      cursor: "pointer"
    },
    style: {
      borderRadius: 9999,
      height: props.size,
      width: props.size
    },
    transition: {
      duration: 240,
      easing: Easing.bezier(0.165, 0.84, 0.44, 1),
      type: "timing"
    }
  })), props.label && /*#__PURE__*/React.createElement(Label, null, props.label));
};
Switch.defaultProps = {
  gutter: 2,
  size: 18
};
//# sourceMappingURL=index.js.map