(function (global, factory) {
  if (typeof define === "function" && define.amd) {
    define(["exports", "core-js/modules/web.dom-collections.iterator.js", "react-native", "@risserlabs/auto-contrast"], factory);
  } else if (typeof exports !== "undefined") {
    factory(exports, require("core-js/modules/web.dom-collections.iterator.js"), require("react-native"), require("@risserlabs/auto-contrast"));
  } else {
    var mod = {
      exports: {}
    };
    factory(mod.exports, global.webDomCollectionsIterator, global.reactNative, global.autoContrast);
    global.util = mod.exports;
  }
})(typeof globalThis !== "undefined" ? globalThis : typeof self !== "undefined" ? self : this, function (_exports, _webDomCollectionsIterator, _reactNative, _autoContrast) {
  "use strict";

  Object.defineProperty(_exports, "__esModule", {
    value: true
  });
  _exports.createUseSplitProps = createUseSplitProps;
  _exports.forwardThemeKey = forwardThemeKey;
  _exports.isText = isText;
  _exports.v = _exports.splitPropsGroups = void 0;

  /**
   * File: /src/util.ts
   * Project: @native-theme-ui/core
   * File Created: 28-02-2022 07:21:50
   * Author: Clay Risser
   * -----
   * Last Modified: 26-10-2022 07:34:17
   * Modified By: Clay Risser
   * -----
   * Risser Labs LLC (c) Copyright 2021 - 2022
   *
   * Licensed under the Apache License, Version 2.0 (the "License");
   * you may not use this file except in compliance with the License.
   * You may obtain a copy of the License at
   *
   *     http://www.apache.org/licenses/LICENSE-2.0
   *
   * Unless required by applicable law or agreed to in writing, software
   * distributed under the License is distributed on an "AS IS" BASIS,
   * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   * See the License for the specific language governing permissions and
   * limitations under the License.
   */

  /* eslint-disable @typescript-eslint/no-explicit-any */
  function createUseSplitProps(propsBuckets, sxBuckets) {
    const lastPropsBucketId = "baseProps";
    const lastSxBucketId = "baseSx";
    const lastStyleBucketId = "baseStyle";
    return (props, sx) => {
      if (!sx) sx = (0, _autoContrast.useCalculatedSx)(props.sx || {});

      const style = _reactNative.StyleSheet.flatten(props.style || {});

      const propsMap = {};
      const styleMap = {};
      const sxMap = {};
      if (lastPropsBucketId) propsMap[lastPropsBucketId] = {};
      if (lastSxBucketId) sxMap[lastSxBucketId] = {};
      if (lastStyleBucketId) styleMap[lastStyleBucketId] = {};

      if (propsBuckets) {
        Object.keys(propsBuckets).forEach(propsBucketId => propsMap[propsBucketId] = {});
        const clonedProps = { ...props
        };
        const propsBucketsIds = Object.keys(propsBuckets);
        Object.entries(clonedProps).forEach(_ref => {
          let [key, prop] = _ref;

          for (const propsBucketId of propsBucketsIds) {
            const propsSet = propsMap[propsBucketId];
            const matcher = propsBuckets[propsBucketId];

            if (match(matcher, key, prop)) {
              propsSet[key] = prop;
              return;
            }
          }

          if (lastPropsBucketId && key !== "sx") propsMap[lastPropsBucketId][key] = prop;
        });
      }

      if (sxBuckets) {
        Object.keys(sxBuckets).forEach(sxBucketId => {
          sxMap[sxBucketId] = {};
          styleMap["".concat(sxBucketId.substring(0, sxBucketId.length - 2), "Style")] = {};
        });
        const sxBucketsIds = Object.keys(sxBuckets);
        Object.entries(sx).forEach(_ref2 => {
          let [key, value] = _ref2;

          for (const sxBucketId of sxBucketsIds) {
            const sxSet = sxMap[sxBucketId];
            const matcher = sxBuckets[sxBucketId];

            if (match(matcher, key, value)) {
              sxSet[key] = value;
              return;
            }
          }

          if (lastSxBucketId) sxMap[lastSxBucketId][key] = value;
        });
        Object.entries(style).forEach(_ref3 => {
          let [key, value] = _ref3;

          for (const sxBucketId of sxBucketsIds) {
            const styleSet = styleMap["".concat(sxBucketId.substring(0, sxBucketId.length - 2), "Style")];
            const matcher = sxBuckets[sxBucketId];

            if (match(matcher, key, value)) {
              styleSet[key] = value;
              return;
            }
          }

          if (lastStyleBucketId) styleMap[lastStyleBucketId][key] = value;
        });
      }

      return { ...propsMap,
        ...sxMap,
        ...styleMap
      };
    };
  } // eslint-disable-next-line @typescript-eslint/no-unused-vars


  function match(matcher, key, value) {
    if (Array.isArray(matcher)) {
      for (let i = 0; i < matcher.length; i++) {
        if (match(matcher[i], key, value)) return true;
      }
    }

    if (matcher instanceof Set) return matcher.has(key);
    if (matcher instanceof RegExp) return !!key.match(matcher);
    return matcher === key;
  }

  const marginArr = ["m", "mb", "ml", "mr", "mt", "mx", "my"];
  const marginRegExp = /^(margin)/g;
  const paddingArr = ["p", "pb", "pl", "pr", "pt", "px", "py"];
  const paddingRegExp = /^(padding)/g;
  const splitPropsGroups = {
    sx: {
      margin: [new Set(marginArr), marginRegExp],
      padding: [new Set(paddingArr), paddingRegExp],
      text: [/^(font)|(text)|(color)/g],
      outer: [new Set(["alignSelf", "justifySelf", "placeSelf", ...marginArr]), marginRegExp],
      inner: [/^flex/g, new Set(["alignContent", "alignItems", "justifyContent", "placeContent", "placeItems", ...paddingArr]), paddingRegExp]
    },
    props: {
      moti: [new Set(["animate", "animateInitialState", "animateSx", "delay", "exit", "exitSx", "exitTransition", "from", "fromSx", "onDidAnimate", "state", "stylePriority", "transition"])],
      pressable: ["onHoverIn", "onHoverOut", "onKeyDown", "onKeyUp", "onLongPress", "onPress", "onPressIn", "onPressOut"]
    }
  };
  _exports.splitPropsGroups = splitPropsGroups;

  function isText(children) {
    if (Array.isArray(children)) {
      return children.length > 1 && typeof children[0] === "string" && "_owner" in children[1] && "_store" in children[1] && "key" in children[1] && "props" in children[1] && "ref" in children[1] && "type" in children[1];
    }

    return typeof children === "string";
  }

  function forwardThemeKey(props, themeKey) {
    return props.themeKey || themeKey;
  }

  const v = variant => variant;

  _exports.v = v;
});
//# sourceMappingURL=util.js.map